==> replicated-config-render-1.0.5.tgz: package/components/ConfigFieldSelectMany.jsx <==
var _ = require('lodash');
var classNames = require('classnames');
var React = require('react');

var ConfigItemTitle = require('./ConfigItemTitle.jsx');
var ConfigFieldCheckbox = require('./ConfigFieldCheckbox.jsx');
var Compat = require('../services/Compat.jsx');

var ConfigFieldSelectMany = React.createClass({
  handleItemChange: function(itemName, value) {
    if (this.props.handleChange) {
      this.props.handleChange(itemName, value);
    }
  },

  render: function() {
    var options = [];
    _.each(this.props.items, function(item) {
      if (!_.isEmpty(item)) {
        // TODO: does required make sense here?
        var title = (
          <ConfigItemTitle
            title={item.title}
            required={item.required === true}
            recommended={item.recommended === true} />
        );

        options.push(
          <div
            key={item.name + '-selectmany'}
            className="pull-left"
            style={{paddingRight: '10px'}}>
            <ConfigFieldCheckbox
              title={title}
              name={item.name}
              group={this.props.name}
              value={item.value}
              default={item.default}
              readOnly={this.props.readOnly}
              handleChange={this.handleItemChange} />
          </div>
        );
      }
    }.bind(this));

    return (
      <div className="field field-type-selectmany">
        <label className={classNames(Compat.hiddenClass('1.0.0'))}>{this.props.title}</label>
        <div className="input input-type-selectmany clearfix">
          {options}
        </div>
      </div>
    );
  }
});

module.exports = ConfigFieldSelectMany;

==> replicated-config-render-1.0.6.tgz: package/components/ConfigFieldSelectMany.jsx <==
var _ = require('lodash');
var classNames = require('classnames');
var React = require('react');

var ConfigItemTitle = require('./ConfigItemTitle.jsx');
var ConfigFieldCheckbox = require('./ConfigFieldCheckbox.jsx');
var Compat = require('../services/Compat');

var ConfigFieldSelectMany = React.createClass({
  handleItemChange: function(itemName, value) {
    if (this.props.handleChange) {
      this.props.handleChange(itemName, value);
    }
  },

  render: function() {
    var options = [];
    _.each(this.props.items, function(item) {
      if (!_.isEmpty(item)) {
        // TODO: does required make sense here?
        var title = (
          <ConfigItemTitle
            title={item.title}
            required={item.required === true}
            recommended={item.recommended === true} />
        );

        options.push(
          <div
            key={item.name + '-selectmany'}
            className="pull-left"
            style={{paddingRight: '10px'}}>
            <ConfigFieldCheckbox
              title={title}
              name={item.name}
              group={this.props.name}
              value={item.value}
              default={item.default}
              readOnly={this.props.readOnly}
              handleChange={this.handleItemChange} />
          </div>
        );
      }
    }.bind(this));

    return (
      <div className="field field-type-selectmany">
        <label className={classNames(Compat.hiddenClass('1.0.0'))}>{this.props.title}</label>
        <div className="input input-type-selectmany clearfix">
          {options}
        </div>
      </div>
    );
  }
});

module.exports = ConfigFieldSelectMany;
